@@ -2,13 +2,11 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Dict
-
 import snowballstemmer
 
 from sphinx.search import SearchLanguage, parse_stop_word
 
-german_stopwords = parse_stop_word('''
+german_stopwords = parse_stop_word("""
 |source: https://snowball.tartarus.org/algorithms/german/stop.txt
 aber           |  but
 
@@ -287,7 +285,7 @@ zum            |  zu + dem
 zur            |  zu + der
 zwar           |  indeed
 zwischen       |  between
-''')
+""")
 
 
 class SearchGerman(SearchLanguage):
